#!/usr/bin/env python
#
# Script: dump_TiePoint2landXML.py
# Purpose : dump data from an existing ContextCapture project
# Keywords: project reading, project data acess
#
# Script description: This script loads a project and dumps project contents to LandXML Surface.
# ******************************************************************************

import sys
import ccmasterkernel
import os
import xml.etree.cElementTree as ET

# Note: replace paths with your references, or install SDK sample data in C:/CC_SDK_DATA
projectDirPath = 'E:/ContextCapture/3Dprojekts-RTK'
outputFilePath = 'E:/ContextCapture/3Dprojekts-RTK/ATPoints-LandXML.xml'

#outputSRS = 'WGS84' # ignored if input block is not georeferenced
outputSRS = 'EPSG:3857' # ignored if input block is not georeferenced

projectName = os.path.basename(projectDirPath)+'.ccm'
projectFilePath = os.path.join(projectDirPath, projectName)

def main():
	print('MasterKernel version %s' % ccmasterkernel.version())
	print('')
	
	# --------------------------------------------------------------------
	# load project
	# --------------------------------------------------------------------
	project = ccmasterkernel.Project()
	err = project.readFromFile(projectFilePath)
	if not err.isNone():
		print('Failed to load project. ' + projectFilePath + ' ' + err.message)
		sys.exit(0)

	print('Project %s successfully loaded.' % project.getName())
	print('')
	

	# --------------------------------------------------------------------
	# display project tree
	# --------------------------------------------------------------------
	for iBlock in range(0, project.getNumBlocks()):
		block = project.getBlock(iBlock)
		print(str(iBlock) + ' -[%s]' % block.getName())
		for iReconstruction in range(0, block.getNumReconstructions()):
			reconstruction = block.getReconstruction(iReconstruction)
			print('	 -[%s]' % reconstruction.getName())
			for iProduction in range(0, reconstruction.getNumProductions()):
				production = reconstruction.getProduction(iProduction)
				print('		 -[%s]' % production.getName())


	print('')
	
	iBlock = input('Enter a number:')
	#print (iBlock)
	if iBlock == '': 
		sys.exit(0)
	print('')
	
	# --------------------------------------------------------------------
	# display block details
	# --------------------------------------------------------------------
	output_SRS = ccmasterkernel.SRS(outputSRS)
	ECEF_SRS = ccmasterkernel.SRS("EPSG:4978")
	fromECEF = ccmasterkernel.SRSTransformation(ECEF_SRS, output_SRS)
	toECEF = ccmasterkernel.SRSTransformation(output_SRS, ECEF_SRS)

	block = project.getBlock(int(iBlock))

	print('--------------------------------------')
	print('Loading: '+'[%s]:' % block.getName())

	# AT
	AT = block.getAT()
	if AT == None:
		print('No Aerotriangulation results')
		sys.exit(0)


	# photogroups/photos
	SparsePoints = block.getNumTiePoints()
	print('NumTiePoints: ' + str(SparsePoints))
	if block.getNumTiePoints() == 0:
		print("Error: Missing tie points.")
		sys.exit(0)
		
	f = open(outputFilePath, 'w')
	#f.write("x,y,z,R,G,B\n")
	numPositionsWritten = 0	
	#point=block.getTiePoint(1)
	#print(type(point))
	#help(ccmasterkernel.bindings.TiePoint)
	#print(point.position.x)
	#print(point.color[1])
	
	#root = ET.Element("LandXML")
	#surfaces = ET.SubElement(root, "Surfaces")
	#surface = ET.SubElement(surfaces, "Surface",name="ATPoints", state="existing")
	#SourceData= ET.SubElement(surfaces, "SourceData")
	#DataPoints= ET.SubElement(SourceData, "DataPoints")
	#ET.SubElement(DataPoints, "PntList3D").text = "1 2 3"
	#tree = ET.ElementTree(root)
	#tree.write(outputFilePath)
	f.write("<LandXML>\n<Surfaces>\n<Surface name=\"ATPoints\" state=\"existing\">\n<SourceData>\n<DataPoints>\n<PntList3D>")

	
	for p in range(0, SparsePoints):
		ATpointpos = block.getTiePoint(p).position
		ATpointRGB = block.getTiePoint(p).color
		if block.isGeoreferenced():
			ATpointpos = fromECEF.transform(ATpointpos)
		f.write(" %s %s %s" % (ATpointpos.x, ATpointpos.y, ATpointpos.z))
		#f.write("%s,%s,%s,%.0f,%.0f,%.0f" % (ATpointpos.x, ATpointpos.y, ATpointpos.z,ATpointRGB[0], ATpointRGB[1], ATpointRGB[2]))
		
		#f.write("\n")
		numPositionsWritten = numPositionsWritten + 1
	f.write("\n</PntList3D>\n</DataPoints>\n</SourceData>\n</Surface>\n</Surfaces>\n</LandXML>")
	f.close()

	
	print('File successfully created: %s' % outputFilePath)
	print('%s points written' % numPositionsWritten)
	
if __name__ == '__main__':
	main()
